import os
import unittest
from shutil import rmtree


class TestInterfaceGenerator(unittest.TestCase):

    def _changeWorkingDirToCurrent(self):
        # Get script absoult path and set it as current work dir
        abspath = os.path.abspath(__file__)
        dname = os.path.dirname(abspath)
        os.chdir(dname)

    @classmethod
    def setUpClass(cls) -> None:
        cls._changeWorkingDirToCurrent(cls)
        params = "-s pp_vault_files/ -r dia_hth_dep -o output_folder/"
        os.system("python3.7 ../../Scripts/InterfaceGenerator.py " + params)

    @classmethod
    def tearDownClass(cls) -> None:
        if os.path.exists("vault.pkl"):
            os.remove("vault.pkl")
        if os.path.exists("output_folder"):
            rmtree("output_folder")

    def test_expect_vault(self):
        self.assertEqual(os.path.exists("vault.pkl"), True, msg="The vault.pkl haven't been created")

    def test_expect_outputs_folder(self):
        self.assertEqual(os.path.exists("output_folder"), True, msg="The output_folder haven't been created")

    def test_outputs_contents(self):
        from itertools import product
        filename="dia_hth_dep_%s"
        with open('helper_files/' + filename % ("template"), 'r') as f:
            template = f.read()

        filename = filename % ("000%i")
        precision_combinations = [('dp', 'dp'), ('dp', 'sp'), ('sp', 'dp'), ('sp', 'sp')]

        for idx, comb in enumerate(precision_combinations):
            with open("output_folder/" + filename % (idx)) as f:
                # Set the params from template correctly
                txt = template % (idx, comb[0], comb[1], idx)

                # split the text by rows
                code = f.read().split('\n')
                txt = txt.split('\n')

                # Check row by row
                self.assertEqual([row.strip() for row in code], [row.strip() for row in txt])


if __name__ == '__main__':
    unittest.main()
