import unittest
import AutoRPE.UtilsRPE.Getter as Getter

class TestGetter(unittest.TestCase):
    def test_type_of_real_cast_with_double_specification(self):
        string = 'real((ssh(:,:,kmm)+ssh_ref)*tmask(:,:,1),dp)'
        self.assertEqual(Getter.get_type_of_real_cast(string), 'double')

    def test_type_of_real_cast_with_single_specification(self):
        string = 'real((ssh(:,:,kmm)+ssh_ref)*tmask(:,:,1),sp)'
        self.assertEqual(Getter.get_type_of_real_cast(string), 'single')

    def test_type_of_real_cast_no_specification(self):
        from AutoRPE.UtilsRPE.VariablePrecision import wp
        string = 'real((ssh(:,:,kmm)+ssh_ref)*tmask(:,:,1))'
        self.assertEqual(Getter.get_type_of_real_cast(string), wp)

    def test_dimension_of_contents_1(self):
        import AutoRPE.UtilsRPE.Getter as Getter
        self.assertEqual(Getter.get_dimension_of_contents("1.0"), 0)

    def test_dimension_of_contents_2(self):
        import AutoRPE.UtilsRPE.Getter as Getter
        string = "real(  ( ( z3d(:,:,:) - e3t_0(:,:,:) ) / e3t_0(:,:,:) * 100 * tmask(:,:,:) ) ** 2  )"
        dimension = Getter.get_dimension_of_contents(string)
        self.assertEqual(dimension, 3)

    def test_dimension_of_contents_3(self):
        import AutoRPE.UtilsRPE.Getter as Getter
        string = "e1e2t(:,:) * zfwf(:,:)"
        dimension = Getter.get_dimension_of_contents(string)
        self.assertEqual(dimension, 2)

    def test_dimension_of_contents(self):
        import AutoRPE.UtilsRPE.Getter as Getter
        cases = [
            ('SUM( a_i(:,:,:)%val - a_i_b(:,:,:)%val, dim=3 )', 2),
            ('SQRT( ( zs1(:,:)%val - zs2(:,:)%val )**2 + 4*zs12(:,:)%val**2 ) * zmsk00(:,:)', 2)
        ]
        for case, answer in cases:
            self.assertEqual(Getter.get_dimension_of_contents(case), answer)

if __name__ == '__main__':
    unittest.main()